@@ -8,10 +8,11 @@ use super::resource::Resource;
 use crate::{
 	global::{
 		edcryptor::EDCryptor,
+		error::InternalError,
+		flags::Flags,
 		header::{Header, HeaderConfig},
 		reg_entry::RegistryEntry,
-		flags::Flags,
-		error::InternalError,
+		result::InternalResult,
 	},
 };
 
@@ -26,7 +27,7 @@ use lz4_flex as lz4;
 #[derive(Debug)]
 pub struct Archive<T> {
 	header: Header,
-	handle: T,
+	handle: BufReader<T>,
 	key: Option<esdalek::PublicKey>,
 	entries: HashMap<String, RegistryEntry>,
 	decryptor: Option<EDCryptor>,
@@ -34,28 +35,32 @@ pub struct Archive<T> {
 
 // INFO: Record Based FileSystem: https://en.wikipedia.org/wiki/Record-oriented_filesystem
 impl<T: Seek + Read> Archive<T> {
-	/// Load an `Archive` with the default settings from a `source.
+	/// Load an `Archive` with the default settings from a source.
 	/// The same as doing:
 	/// ```ignore
 	/// Archive::with_config(HANDLE, &HeaderConfig::default())?;
 	/// ```
+	/// ### Errors
+	/// If parsing fails, an `Err(-)` is returned.
 	#[inline(always)]
-	pub fn from_handle(handle: T) -> Result<Archive<impl Seek + Read>, InternalError> {
+	pub fn from_handle(handle: T) -> InternalResult<Archive<T>> {
 		Archive::with_config(handle, &HeaderConfig::default())
 	}
 
 	/// Given a read handle, this will read and parse the data into an `Archive` struct.
 	/// Provide a reference to `HeaderConfig` and it will be used to validate the source and for further configuration.
-	/// If parsing fails, an `Err()` is returned.
+	/// ### Errors
+	/// If parsing fails, an `Err(-)` is returned.
 	pub fn with_config(
 		mut handle: T, config: &HeaderConfig,
-	) -> Result<Archive<impl Seek + Read>, InternalError> {
+	) -> InternalResult<Archive<T>> {
 		let header = Header::from_handle(&mut handle)?;
 		Header::validate(&header, config)?;
 
 		// Generate and store Registry EntriesF
 		let mut use_decryption = false;
 		let mut entries = HashMap::new();
+
 		for _ in 0..header.capacity {
 			let (entry, id) = RegistryEntry::from_handle(&mut handle)?;
 			if entry.flags.contains(Flags::ENCRYPTED_FLAG) && !use_decryption {
@@ -84,7 +89,7 @@ impl<T: Seek + Read> Archive<T> {
 
 	/// Fetch a `Resource` with the given `ID`.
 	/// If the `ID` does not exist within the source, `Err(---)` is returned.
-	pub fn fetch(&mut self, id: &str) -> Result<Resource, InternalError> {
+	pub fn fetch(&mut self, id: &str) -> InternalResult<Resource> {
 		let mut buffer = Vec::new();
 		let (flags, content_version, validated) = self.fetch_write(id, &mut buffer)?;
 
@@ -100,7 +105,7 @@ impl<T: Seek + Read> Archive<T> {
 	/// Returns a tuple containing the `Flags`, `content_version` and `secure`, ie validity, of the data.
 	pub fn fetch_write<W: Write>(
 		&mut self, id: &str, mut target: W,
-	) -> Result<(Flags, u8, bool), InternalError> {
+	) -> InternalResult<(Flags, u8, bool)> {
 		if let Some(entry) = self.fetch_entry(id) {
 			let handle = &mut self.handle;
 			let mut is_secure = false;
@@ -130,7 +135,11 @@ impl<T: Seek + Read> Archive<T> {
 					raw = match dx.decrypt(&raw) {
 						Ok(bytes) => bytes,
 						Err(err) => {
-							return Err(InternalError::DecryptionError(id.to_string(), err));
+							return Err(InternalError::CryptoError(format!(
+								"Unable to decrypt resource: {}. Error: {}",
+								id.to_string(),
+								err
+							)));
 						}
 					};
 				} else {
@@ -160,10 +169,12 @@ impl<T: Seek + Read> Archive<T> {
 						));
 					}
 					Some(_) => return self.fetch_write(&target_id, target),
-					None => return Err(InternalError::MissingResourceError(format!(
+					None => {
+						return Err(InternalError::MissingResourceError(format!(
 						"The linking Leaf: {} exists, but the Leaf it links to: {}, does not exist",
 						id, target_id
-					))),
+					)))
+					}
 				};
 			};
 
@@ -206,7 +217,7 @@ impl Default for Archive<&[u8]> {
 	fn default() -> Archive<&'static [u8]> {
 		Archive {
 			header: Header::default(),
-			handle: &[],
+			handle: BufReader::new(&[]),
 			key: None,
 			entries: HashMap::new(),
 			decryptor: None,
