@@ -2,7 +2,7 @@ use ed25519_dalek as esdalek;
 use rand::rngs::OsRng;
 use std::{io::Read};
 
-use crate::global::error::InternalError;
+use crate::global::{error::InternalError, result::InternalResult};
 
 /// Use this function to easily generate a [Keypair](https://docs.rs/ed25519-dalek/1.0.1/ed25519_dalek/struct.Keypair.html) using `OsRng`
 #[inline(always)]
@@ -11,7 +11,9 @@ pub fn gen_keypair() -> esdalek::Keypair {
 }
 
 /// Use this to read and parse a `Keypair` from a `io::Read` handle
-pub fn read_keypair<R: Read>(mut handle: R) -> Result<esdalek::Keypair, InternalError> {
+/// ### Errors
+/// If the data can't be parsed into a keypair
+pub fn read_keypair<R: Read>(mut handle: R) -> InternalResult<esdalek::Keypair> {
 	let mut keypair_bytes = [0; crate::KEYPAIR_LENGTH];
 	handle.read_exact(&mut keypair_bytes)?;
 	Ok(match esdalek::Keypair::from_bytes(&keypair_bytes) {
