@@ -1,4 +1,4 @@
-use crate::global::{error::InternalError, flags::Flags};
+use crate::global::{flags::Flags, result::InternalResult};
 use std::io;
 use ed25519_dalek as esdalek;
 
@@ -43,7 +43,9 @@ impl BuilderConfig {
 
 	// Keypair helpers
 	/// Parses and stores a keypair from a source.
-	pub fn load_keypair<T: io::Read>(&mut self, handle: T) -> Result<(), InternalError> {
+	/// ### Errors
+	/// If the call to `::utils::read_keypair()` fails to parse the data from the handle
+	pub fn load_keypair<T: io::Read>(&mut self, handle: T) -> InternalResult<()> {
 		self.keypair = Some(crate::utils::read_keypair(handle)?);
 		Ok(())
 	}
