@@ -5,6 +5,7 @@ mod config;
 pub use config::BuilderConfig;
 use super::leaf::{Leaf, CompressMode};
 use crate::global::error::InternalError;
+use crate::global::result::InternalResult;
 use crate::{
 	global::{edcryptor::EDCryptor, header::Header, reg_entry::RegistryEntry, flags::Flags},
 };
@@ -40,8 +41,9 @@ impl<'a> Builder<'a> {
 	/// Appends a read handle wrapped in a `Leaf` into the processing queue.
 	/// The `data` is wrapped in the default `Leaf`.
 	/// The second argument is the `ID` with which the embedded data will be tagged
-	/// Returns an Er(---) if a Leaf with the specified ID exists.
-	pub fn add<D: Read + 'a>(&mut self, data: D, id: &str) -> Result<(), InternalError> {
+	/// ### Errors
+	/// Returns an `Err(())` if a Leaf with the specified ID exists.
+	pub fn add<D: Read + 'a>(&mut self, data: D, id: &str) -> InternalResult<()> {
 		let leaf = Leaf::from_handle(data).id(id).template(&self.leaf_template);
 		self.add_leaf(leaf)?;
 		Ok(())
@@ -53,7 +55,7 @@ impl<'a> Builder<'a> {
 	/// ## Errors
 	/// - Any of the underlying calls to the filesystem fail.
 	/// - The internal call to `Builder::add_leaf()` returns an error.
-	pub fn add_dir(&mut self, path: &str, template: Option<&Leaf>) -> Result<(), InternalError> {
+	pub fn add_dir(&mut self, path: &str, template: Option<&Leaf>) -> InternalResult<()> {
 		use std::fs;
 
 		let directory = fs::read_dir(path)?;
@@ -88,11 +90,11 @@ impl<'a> Builder<'a> {
 	/// `Leaf`s added directly do not implement data from the `Builder`s internal template.
 	/// ### Errors
 	/// - Returns an error if a `Leaf` with the specified `ID` exists.
-	pub fn add_leaf(&mut self, leaf: Leaf<'a>) -> Result<(), InternalError> {
+	pub fn add_leaf(&mut self, leaf: Leaf<'a>) -> InternalResult<()> {
 		{
 			// Make sure no two leaves are written with the same ID
 			if !self.id_set.insert(leaf.id.clone()) {
-				return Err(InternalError::LeafAppendError(format!("A leaf with the ID: {} already exists. Consider changing the ID to prevent collisions", leaf.id)));
+				return Err(InternalError::LeafAppendError(leaf.id));
 			};
 		}
 
@@ -124,7 +126,7 @@ impl<'a> Builder<'a> {
 	/// - If the requirements of a given stage, compression or encryption, are not met. Like not providing a keypair if a `Leaf` is to be encrypted.
 	pub fn dump<W: Write + Seek>(
 		&mut self, mut target: W, config: &BuilderConfig,
-	) -> Result<usize, InternalError> {
+	) -> InternalResult<usize> {
 		// Keep track of how many bytes are written, and where bytes are being written
 		let mut size = 0usize;
 		let mut reg_offset = 0;
@@ -242,7 +244,10 @@ impl<'a> Builder<'a> {
 					leaf_bytes = match ex.encrypt(&leaf_bytes) {
 						Ok(bytes) => bytes,
 						Err(err) => {
-							return Err(InternalError::EncryptionError(leaf.id.clone(), err))
+							return Err(InternalError::CryptoError(format!(
+								"Unable to encrypt leaf: {}. Error: {}",
+								leaf.id, err
+							)))
 						}
 					};
 
